package web.technics;

import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import net.bo.Application;
import net.bo.Utilisateur;

/**
 * Classe passerelle entre métier et session HTTP
 * @author jc
 *
 */
public class GatewaySession {
	/**
	 * Retourne l'instance d'application active
	 * @param request requête HTTP
	 * @return instance d'application active
	 */
	public static Application getApplication(HttpServletRequest request){
		return Utils.getSessionApp(request.getSession()).getApplication();
	}
	
	/**
	 * Retourne la liste des utilisateurs en session
	 * @param request requête HTTP
	 * @return Map des utilisateurs
	 */
	public static Map<String, Utilisateur> getUtilisateurs(HttpServletRequest request){
		return getApplication(request).getLesUtilisateurs();
	}
	

	/**
	 * Retourne l'utilisateur d'identifiant id et stocké en session
	 * @param request requête HTTP
	 * @param id
	 * @return utilisateur correspondant
	 */
	public static Utilisateur getOneUser(HttpServletRequest request,String id){
		Utilisateur result=null;
		if(id!=null && !"".equals(id))
			result= getApplication(request).getLesUtilisateurs().get(id);
		return result;
	}
	
	/**
	 * Retourne l'utilisateur dont l'identifiant id est passé en paramétre de la requête et stocké en session 
	 * @param request requête HTTP
	 * @return utilisateur correspondant
	 */
	public static Utilisateur getOneUser(HttpServletRequest request){
		String id=request.getParameter("id");
		return getOneUser(request, id);
	}
}
