package web.technics;
/**
 * Classe permettant l'exécution de scripts côté client utilisant forms.js
 * @author jc
 *
 */
public class JSFormsUtils {
	/**
	 * Ajoute les balises de Script avant et après le code si nécessaire
	 */
	private static String addScript(String code){
		return code.replaceAll("(\\<script[^>]*?\\>)?(.*)(\\<\\/script\\>)?", "<script>$2 </script>\n");
	}
	
	/**
	 * Associe une fonction à l'évènement d'un élément DOM
	 */
	public static String bindToElement(String element,String event,String function){
		return addScript("Forms.DOM.bind('"+element+"','"+event+"',"+function+");");
	}
	
	/**
	 * Exécute le script passé en paramètre
	 * @param script
	 * @return mixed
	 */
	public static String execute(String script){
		return addScript(script);
	}

	public static String  _get(String url){
		return _get(url, "undefined", "", null);
	}
	public static String  _get(String url,String params){
		return _get(url, params, "", null);
	}
	public static String  _get(String url,String params,String responseElement){
		return _get(url, params, responseElement, null);
	}
	public static String  _get(String url,String params,String responseElement,String function){
		String retour="Forms.Utils.get('"+responseElement+"','"+url+"','"+params+"',"+function+");";
		return retour;
	}
	
	public static String get(String url){
		return addScript(_get(url));
	}
	public static String get(String url,String params){
		return addScript(_get(url,params));
	}
	public static String get(String url,String params,String responseElement){
		return addScript(_get(url,params,responseElement));
	}
	/**
	 * Effectue un GET en ajax
	 * @param url Adresse de la requête
	 * @param params Paramètres passés au format JSON
	 * @param responseElement id de l'élément HTML affichant la réponse
	 * @param function fonction appelée éventuellement après réception
	 */
	public static String get(String url,String params,String responseElement,String function){
		return addScript(_get(url,params,responseElement,function));
	}
	
	/**
	 * @param url
	 * @param params
	 * @param responseElement
	 * @param function
	 */
	public static String _post(String url,String params,String responseElement,String function){
		String retour="Forms.Utils.post('"+responseElement+"','"+url+"','"+params+"',"+function+")";
		return retour;
	}
	/**
	 * Effectue un POST en ajax
	 * @param url Adresse de la requête
	 */
	public static String  post(String url){
				return post(url, "undefined", "", null);
	}
	/**
	 * Effectue un POST en ajax
	 * @param url Adresse de la requête
	 * @param params Paramètres passés au format JSON
	 */
	public static String  post(String url,String params){
				return post(url, params, "", null);
	}
	
	/**
	 * Effectue un POST en ajax
	 * @param url Adresse de la requête
	 * @param params Paramètres passés au format JSON
	 * @param responseElement id de l'élément HTML affichant la réponse
	 */
	public static String  post(String url,String params,String responseElement){
				return post(url, params, responseElement, null);
	}
	/**
	 * Effectue un POST en ajax
	 * @param url Adresse de la requête
	 * @param params Paramètres passés au format JSON
	 * @param responseElement id de l'élément HTML affichant la réponse
	 * @param function fonction appelée éventuellement après réception
	 */
	public static String  post(String url,String params,String responseElement,String function){
				return addScript(_post(url,params,responseElement,function));
		
	}
	public static String  _postForm(String url,String form,String responseElement){
		return _postForm(url, form, responseElement, false, null);
	}
	public static String  _postForm(String url,String form,String responseElement,boolean validation){
		return _postForm(url, form, responseElement, validation, null);
	}
	public static String  _postForm(String url,String form,String responseElement,boolean validation,String function){
		String retour="Forms.Utils.postForm('"+form+"','"+responseElement+"','"+url+"',undefined,"+function+")";
		return retour;
	}
	
	public static String  postForm(String url,String form,String responseElement){
		return postForm(url, form, responseElement, false, null);
	}
	public static String  postForm(String url,String form,String responseElement,boolean validation){
		return postForm(url, form, responseElement, validation, null);
	}
	/**
	 * Effectue un POST d'un formulaire en ajax
	 * @param url Adresse de la requête
	 * @param form id du formulaire à poster
	 * @param responseElement id de l'élément HTML affichant la réponse
	 * @param function fonction appelée éventuellement après réception
	 */
	public static String  postForm(String url,String form,String responseElement,boolean validation,String function){
		return addScript(_postForm(url, form, responseElement,validation,function));
	}
	
	public static String  _setVal(String element,String value){
		return _setVal(element, value, "");
	}
	
	public static String  _setVal(String element,String value,String script){
		return "$('"+element+"').value="+value+";\n"+script;
	}
	
	public static String  setVal(String element,String value){
		return setVal(element, value, "");
	}
	/**
	 * Affecte une valeur à un élément HTML
	 * @param element
	 * @param value
	 */
	public static String  setVal(String element,String value,String script){
		return addScript(_setVal(element,value,script));
	}
	
	public static String  _setHtml(String element){
		return _setHtml(element, "", "");
	}
	public static String  _setHtml(String element,String html){
		return _setHtml(element, html, "");
	}
	public static String  _setHtml(String element,String html,String script){
		return "Forms.Utils.setInnerHTML($('"+element+"'),'"+html+"');\n"+script;
	}
	
	
	public static String  setHtml(String element){
		return setHtml(element, "", "");
	}
	public static String  setHtml(String element,String html){
		return setHtml(element, html, "");
	}
	/**
	 * Affecte du html à un élément
	 * @param element
	 * @param html
	 */
	public static String  setHtml(String element,String html,String script){
		return addScript(_setHtml(element, html,script));
	}
	
	
	public static String  _setAttr(String element,String attr){
		return _setAttr(element, attr, "", "");
	}
	public static String  _setAttr(String element,String attr,String value){
		return _setAttr(element, attr, value, "");
	}
	public static String  _setAttr(String element,String attr,String value,String script){
		return "$('"+element+"')."+attr+"="+value+";\n"+script;
	}
	
	public static String  setAttr(String element,String attr){
		return setAttr(element, attr, "", "");
	}
	public static String  setAttr(String element,String attr,String value){
		return setAttr(element, attr, value, "");
	}
	/**
	 * Modifie l'attribut $attr d'un élément html
	 * @param element
	 * @param attr attribut à modifier
	 * @param value nouvelle valeur
	 */
	public static String  setAttr(String element,String attr,String value,String script){
		return addScript(_setAttr(element, attr, value,script));
	}

	public static String _doSomethingOn(String element,String someThing){
		return _doSomethingOn(element, someThing, "", "");
	}
	public static String _doSomethingOn(String element,String someThing,String param){
		return _doSomethingOn(element, someThing, param, "");
	}
	/**
	 * Appelle la méthode someThing sur chaque element du selector avec passage éventuel des paramètres params
	 * @param selector
	 * @param someThing
	 * @param params
	 * @return mixed
	 */	
	public static String _doSomethingOn(String selector,String someThing,String params,String function){
		return "(new Forms.Elements('"+selector+"')).each(function(k,v){("+function+")(v,"+params+");});";
	}
	
	public static String doSomethingOn(String element,String someThing){
		return doSomethingOn(element, someThing, "", "");
	}
	public static String doSomethingOn(String element,String someThing,String param){
		return doSomethingOn(element, someThing, param, "");
	}
	/**
	 * Appelle la méthode JQuery $someThing sur $element avec passage éventuel du paramètre $param
	 * @param element
	 * @param someThing
	 * @param param
	 * @return mixed
	 */
	public static String doSomethingOn(String element,String someThing,String param,String function){
		return addScript(_doSomethingOn(element, someThing,param,function));
	}
	
	 public static String getAndBindTo(String element,String event,String url){
		return getAndBindTo(element, event, url, "undefined", "", null);
	}
	 public static String getAndBindTo(String element,String event,String url,String params){
		return getAndBindTo(element, event, url, params, "", null);
	}
	 public static String getAndBindTo(String element,String event,String url,String params,String responseElement){
		return getAndBindTo(element, event, url, params, responseElement, null);
	}
	/**
	 * Effectue un get vers $url sur l'évènement $event de $element en passant les paramètres $params
	 * puis affiche le résultat dans $responseElement
	 * @param element
	 * @param event
	 * @param url
	 * @param params
	 * @param responseElement
	 * @param function
	 */
	 public static String getAndBindTo(String element,String event,String url,String params,String responseElement,String function){
		return bindToElement(element, event,"function(event){"+_get(url, params,responseElement,function)+"}");
	}
		
	 public static String postAndBindTo(String element,String event,String url){
			return postAndBindTo(element, event, url, "undefined", "", null);
		}
	 public static String postAndBindTo(String element,String event,String url,String params){
			return postAndBindTo(element, event, url, params, "", null);
		}
		public static String postAndBindTo(String element,String event,String url,String params,String responseElement){
			return postAndBindTo(element, event, url, params, responseElement, null);
		}
	/**
	 * Effectue un post vers $url sur l'évènement $event de $element en passant les paramètres $params
	 * puis affiche le résultat dans $responseElement
	 * @param element
	 * @param event
	 * @param url
	 * @param params
	 * @param responseElement
	 * @param function
	 */
	public static String postAndBindTo(String element,String event,String url,String params,String responseElement,String function){
		return bindToElement(element, event,"function(event){"+_post(url,params,responseElement,function)+"}");
	}

	public static String postFormAndBindTo(String element,String event,String url,String form){
		return postFormAndBindTo(element,event,url,form,"",false,null);
	}
	public static String postFormAndBindTo(String element,String event,String url,String form,String responseElement){
		return postFormAndBindTo(element,event,url,form,responseElement,false,null);
	}
	public static String postFormAndBindTo(String element,String event,String url,String form,String responseElement,boolean validation){
		return postFormAndBindTo(element,event,url,form,responseElement,validation,null);
	}
	/**
	 * Effectue un post vers $url sur l'évènement $event de $element en passant les paramètres du formulaire $form
	 * puis affiche le résultat dans $responseElement
	 * @param element
	 * @param event
	 * @param url
	 * @param form
	 * @param responseElement
	 * @param function
	 */
	public static String postFormAndBindTo(String element,String event,String url,String form,String responseElement,boolean validation,String function){
		return bindToElement(element, event,"function(event){"+_postForm(url,form,responseElement,validation,function)+"}");
	}
	
	public static String setAndBindTo(String element,String event,String elementToModify){
		return setAndBindTo(element, event, elementToModify, "", "");
	}
	public static String setAndBindTo(String element,String event,String elementToModify,String value){
		return setAndBindTo(element, event, elementToModify, value, "");
	}
	/**
	 * Modifie la valeur de $elementToModify et lui affecte $valeur sur l'évènement $event de $element
	 * @param element
	 * @param event
	 * @param elementToModify
	 * @param value
	 * @return mixed
	 */
	public static String setAndBindTo(String element,String event,String elementToModify,String value,String function){
		return bindToElement(element, event,"function(event){"+_setVal(elementToModify, value,function)+"}");
	}

	public static String setHtmlAndBindTo(String element,String event,String elementToModify){
		return setHtmlAndBindTo(element, event, elementToModify, "", "");
	}
	public static String setHtmlAndBindTo(String element,String event,String elementToModify,String value){
		return setHtmlAndBindTo(element, event, elementToModify, value, "");
	}
	/**
	 * Modifie la valeur de elementToModify et lui affecte valeur sur l'évènement event de @param element
	 * @param element
	 * @param event
	 * @param elementToModify
	 * @param value
	 * @return mixed
	 */
	public static String setHtmlAndBindTo(String element,String event,String elementToModify,String value,String function){
		return bindToElement(element, event,"function(event){"+_setHtml(elementToModify, value,function)+"}");
	}
	
	public static String doSomeThingAndBindTo(String element,String event,String elementToModify,String someThing){
		return doSomeThingAndBindTo(element, event, elementToModify, someThing, "", "");
	}
	public static String doSomeThingAndBindTo(String element,String event,String elementToModify,String someThing,String param){
		return doSomeThingAndBindTo(element, event, elementToModify, someThing, param, "");
	}
	/**
	 * 
	 * @param element
	 * @param event
	 * @param element
	 * @param someThing
	 * @param param
	 */
	public static String doSomeThingAndBindTo(String element,String event,String elementToModify,String someThing,String param,String function){
		return bindToElement(element, event,"function(event){"+_doSomethingOn(elementToModify, someThing,param,function)+"}");
	}
	public static String _onDOMReady(String script){
		return "Forms.DOM.onReady(function(){"+script+"});\n";
	}
	public static String onDOMReady(String script){
		return addScript(_onDOMReady(script));
	}
}
